@@ -1,15 +1,14 @@
-# Copyright (c) 2010 CentralNic Ltd. All rights reserved. This program is
+# Copyright (c) 2011 CentralNic Ltd. All rights reserved. This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as Perl itself.
 # 
-# $Id: Simple.pm,v 1.10 2008/04/08 12:57:11 gavin Exp $
+# $Id: Simple.pm,v 1.10 2011/04/08 12:57:11 gavin Exp $
 package Net::EPP::Simple;
 use Carp;
 use Digest::SHA1 qw(sha1_hex);
 use Net::EPP::Frame;
 use Net::EPP::ResponseCodes;
 use Time::HiRes qw(time);
-use UNIVERSAL qw(isa);
 use base qw(Net::EPP::Client);
 use constant EPP_XMLNS	=> 'urn:ietf:params:xml:ns:epp-1.0';
 use vars qw($Error $Code $Message);
@@ -85,6 +84,8 @@ one for C<Net::EPP::Client>, but with the following exceptions:
 
 =item * C<reconnect> can be used to disable automatic reconnection (it is enabled by default). Before sending a frame to the server, C<Net::EPP::Simple> will send a C<E<lt>helloE<gt>> to check that the connection is up, if not, it will try to reconnect, aborting after the I<n>th time, where I<n> is the value of C<reconnect> (the default is 3).
 
+=item * C<login> can be used to disable automatic logins. If you set it to C<0>, you can manually log in using the C<$epp->_login()> method.
+
 =back
 
 The constructor will establish a connection to the server and retrieve the
@@ -377,6 +378,8 @@ following:
 
 =item * C<1> if the object is available.
 
+=back
+
 =cut
 
 sub check_domain {
@@ -616,15 +619,15 @@ like this:
 	  ],
 	  'authInfo' => 'abc-12345',
 	  'name' => 'example.tld',
-	  'trDate' => '2007-01-18T11:08:03.0Z',
+	  'trDate' => '2011-01-18T11:08:03.0Z',
 	  'ns' => [
 	    'ns0.example.com',
 	    'ns1.example.com',
 	  ],
-	  'crDate' => '2001-02-16T12:06:31.0Z',
-	  'exDate' => '2009-02-16T12:06:31.0Z',
+	  'crDate' => '2011-02-16T12:06:31.0Z',
+	  'exDate' => '2011-02-16T12:06:31.0Z',
 	  'crID' => 'registrar-id',
-	  'upDate' => '2007-08-29T04:02:12.0Z',
+	  'upDate' => '2011-08-29T04:02:12.0Z',
 	  hosts => [
 	    'ns0.example.tld',
 	    'ns1.example.tld',
@@ -725,7 +728,7 @@ The hash ref returned by C<host_info()> will usually look something like
 this:
 
 	$info = {
-	  'crDate' => '2007-09-17T15:38:56.0Z',
+	  'crDate' => '2011-09-17T15:38:56.0Z',
 	  'clID' => 'registrar-id',
 	  'crID' => 'registrar-id',
 	  'roid' => 'tld-12345',
@@ -780,7 +783,7 @@ like this:
 	        ],
 	        'city' => 'Dulles',
 	        'sp' => 'VA',
-	        'pc' => '20166-6503'
+	        'pc' => '20116-6503'
 	        'cc' => 'US',
 	      }
 	    }
@@ -794,7 +797,7 @@ like this:
 	  'voice' => '+1.7035555555x1234',
 	  'fax' => '+1.7035555556',
 	  'email' => 'jdoe@example.com',
-	  'crDate' => '2007-09-23T03:51:29.0Z',
+	  'crDate' => '2011-09-23T03:51:29.0Z',
 	  'upDate' => '1999-11-30T00:00:00.0Z'
 	};
 
@@ -895,9 +898,9 @@ methods will return a hash ref that looks like this:
 	my $trnData = {
 	  'name' => 'example.tld',
 	  'reID' => 'losing-registrar',
-	  'acDate' => '2007-12-04T12:24:53.0Z',
+	  'acDate' => '2011-12-04T12:24:53.0Z',
 	  'acID' => 'gaining-registrar',
-	  'reDate' => '2007-11-29T12:24:53.0Z',
+	  'reDate' => '2011-11-29T12:24:53.0Z',
 	  'trStatus' => 'pending'
 	};
 
@@ -1270,7 +1273,7 @@ sub ping {
 	my $hello = Net::EPP::Frame::Hello->new;
 	my $response = $self->request($hello);
 
-	return (isa($response, 'XML::LibXML::Document') ? 1 : undef);
+	return (UNIVERSAL::isa($response, 'XML::LibXML::Document') ? 1 : undef);
 }
 
 sub _request {
@@ -1327,10 +1330,10 @@ sub request {
 	$Error		= '';
 	$Message	= '';
 
-	$frame->clTRID->appendText(sha1_hex(ref($self).time().$$)) if (isa($frame, 'Net::EPP::Frame::Command'));
+	$frame->clTRID->appendText(sha1_hex(ref($self).time().$$)) if (UNIVERSAL::isa($frame, 'Net::EPP::Frame::Command'));
 
 	$self->debug(sprintf('sending a %s to the server', ref($frame)));
-	if (isa($frame, 'XML::LibXML::Document')) {
+	if (UNIVERSAL::isa($frame, 'XML::LibXML::Document')) {
 		map { $self->debug('C: '.$_) } split(/\n/, $frame->toString(1));
 
 	} else {
@@ -1340,7 +1343,7 @@ sub request {
 
 	my $response = $self->SUPER::request($frame);
 
-	map { $self->debug('S: '.$_) } split(/\n/, $response->toString(1)) if (isa($response, 'XML::LibXML::Document'));
+	map { $self->debug('S: '.$_) } split(/\n/, $response->toString(1)) if (UNIVERSAL::isa($response, 'XML::LibXML::Document'));
 
 	return $response;
 }
@@ -1448,7 +1451,7 @@ C<E<lt>msgE<gt>> element in the response frame for the last transaction.
 This variable contains the integer result code returned by the server
 for the last transaction. A successful transaction will always return an
 error code of 1999 or lower, for an unsuccessful transaction it will be
-2000 or more. If there is an internal client error (due to invalid
+2011 or more. If there is an internal client error (due to invalid
 parameters being passed to a method, or a network error) then this will
 be set to 2400 (C<COMMAND_FAILED>). See L<Net::EPP::ResponseCodes> for
 more information about thes codes.
